@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0405';
+our $VERSION = '0.0406';
 
 use Moo;
 use strictures 2;
@@ -172,15 +172,15 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0405
+version 0.0406
 
 =head1 SYNOPSIS
 
   use MIDI::RtController ();
 
   my $rtc = MIDI::RtController->new(
-    input  => 'input-MIDI-device',
-    output => 'output-MIDI-device',
+    input  => 'input device 1',
+    output => 'output device',
   );
 
   sub filter_notes {
@@ -212,10 +212,17 @@ version 0.0405
     }
   );
 
-  # add other stuff to the $rtc->loop...
-
+  # add stuff to the $rtc->loop...
   $rtc->run;
 
+  # you can also use multiple input sources simultaneously:
+  my $rtc2 = MIDI::RtController->new(
+    loop   => $rtc->loop,
+    input  => 'input device 2',
+    output => 'output device',
+  );
+  $rtc2->run;
+
 =head1 DESCRIPTION
 
 C<MIDI::RtController> allows you to control your MIDI controller using
